@@ -6,8 +6,4 @@ Create DataFrame string representations that can be used to create new DataFrame
 from ._pdrepr import pdrepr
 
 
-__author__ = 'Daniel Hjertholm'
-__version__ = '0.1.0'
-
-
-__all__ = [pdrepr]
\ No newline at end of file
+__all__ = [pdrepr]
